import os
import glob
import argparse
from Bio import SeqIO
from itertools import groupby

from Bio import SeqIO


# total_len = 0
# for each_seq in SeqIO.parse('assembly_graph_NoEu.gfa_reads_min0bp.fastq', 'fastq'):
#     total_len += len(each_seq.seq)
#
# print(total_len)
# print(total_len/(1024*1024*1024))


def cigar_to_aln_len(cigar_string):
    # Given a CIGAR string, return the number of bases consumed from the query sequence
    read_consuming_ops = ("M", "I", "S", "=", "X")
    result = 0
    cig_iter = groupby(cigar_string, lambda chr: chr.isdigit())
    for _, length_digits in cig_iter:
        length = int(''.join(length_digits))
        op = next(next(cig_iter)[1])
        if op in ("M", "=", "X"):
            print(op)
            result += length
    return result


cigar_to_aln_len('8H42M1I2M1D33M1D66M1D15M')


import argparse
from Bio import SeqIO


def rm_short_reads(args):

    reads_file        = args['i']
    min_read_len      = args['l']
    output_reads_file = args['o']
    in_fastq          = args['fq']

    seq_in_format = 'fasta'
    if in_fastq is True:
        seq_in_format = 'fastq'

    output_reads_file_handle = open(output_reads_file, 'w')
    for each_read in SeqIO.parse(reads_file, seq_in_format):
        if len(each_read.seq) >= min_read_len:
            if seq_in_format == 'fasta':
                output_reads_file_handle.write('>%s\n' % each_read.id)
                output_reads_file_handle.write('%s\n' % str(each_read.seq))
            elif seq_in_format == 'fastq':
                SeqIO.write(each_read, output_reads_file_handle, 'fastq')
    output_reads_file_handle.close()


if __name__ == '__main__':

    parser = argparse.ArgumentParser()
    parser.add_argument('-i',   required=True,                        help='input file')
    parser.add_argument('-l',   required=True, type=int,              help='read length cutoff (bp)')
    parser.add_argument('-o',   required=True,                        help='output file')
    parser.add_argument('-fq',  required=False, action="store_true",  help='in fastq format, default: fa')
    args = vars(parser.parse_args())
    rm_short_reads(args)
